# Deklaration der Mengen
set Gemuese; # Menge von  verschiedenen Gemüsesorten

# Deklaration von skalaren Parameter
param kapfl > 0; # maximale Fläche
param kapst > 0; # maximale Arbeitsstunden
param kapwa > 0; # maximale Wassermenge
param kapdu > 0; # maximale Düngemittel

# Deklaration von indizierten Parameter
param arbst {Gemuese} >= 0; # Arbeitsstunden pro Gemüse 
param wasser {Gemuese} >= 0; # Menge an Wasser pro Gemüse
param dueng {Gemuese} >= 0; # Duengemittel pro Gemüse
param deckb {Gemuese} >= 0; # Höhe des Deckungsbeitrag pro Gemüse

# Deklaration der Variablen mit Nichtnegativitätsbedingung
var xgem {j in Gemuese} >= 0; # Variable für einzelne Gemüsemengen 

# Maximierung des Deckungsbeitrags
maximize Deckungsbeitrag: sum {j in Gemuese} deckb[j] * xgem[j];

# Flächenkapazität
subject to KapFlaeche: sum {j in Gemuese} xgem[j] <= kapfl;

# Wasserkapazität
s.t. KapWasser: sum {j in Gemuese} wasser[j] * xgem[j] <= kapwa;

# Arbeitsstundenkapazität
s.t. KapArbeit: sum {j in Gemuese} arbst[j] * xgem[j] <= kapst;

# Düngemittlekapazität
s.t. KapDuengemittel: sum {j in Gemuese} dueng[j] * xgem[j] <= kapdu;
